Class: SignRequestClient::SignRequestQuickCreate
- Inherits:
-
Object
- Object
- SignRequestClient::SignRequestQuickCreate
- Defined in:
- lib/signrequest_client/models/sign_request_quick_create.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_delete_days ⇒ Object
Returns the value of attribute auto_delete_days.
-
#disable_attachments ⇒ Object
Returns the value of attribute disable_attachments.
-
#disable_date ⇒ Object
Returns the value of attribute disable_date.
-
#disable_emails ⇒ Object
Returns the value of attribute disable_emails.
-
#disable_text ⇒ Object
Returns the value of attribute disable_text.
-
#disable_text_signatures ⇒ Object
Returns the value of attribute disable_text_signatures.
-
#disable_upload_signatures ⇒ Object
Returns the value of attribute disable_upload_signatures.
-
#document ⇒ Object
Returns the value of attribute document.
-
#events_callback_url ⇒ Object
Returns the value of attribute events_callback_url.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#file ⇒ Object
Returns the value of attribute file.
-
#file_from_content ⇒ Object
Returns the value of attribute file_from_content.
-
#file_from_content_name ⇒ Object
Returns the value of attribute file_from_content_name.
-
#file_from_sf ⇒ Object
Returns the value of attribute file_from_sf.
-
#file_from_url ⇒ Object
Returns the value of attribute file_from_url.
-
#from_email ⇒ Object
Returns the value of attribute from_email.
-
#from_email_name ⇒ Object
Returns the value of attribute from_email_name.
-
#frontend_id ⇒ Object
Returns the value of attribute frontend_id.
-
#integration ⇒ Object
Returns the value of attribute integration.
-
#integration_data ⇒ Object
Returns the value of attribute integration_data.
-
#integrations ⇒ Object
Returns the value of attribute integrations.
-
#is_being_prepared ⇒ Object
Returns the value of attribute is_being_prepared.
-
#message ⇒ Object
Returns the value of attribute message.
-
#name ⇒ Object
Returns the value of attribute name.
-
#prefill_tags ⇒ Object
Returns the value of attribute prefill_tags.
-
#prepare_url ⇒ Object
Returns the value of attribute prepare_url.
-
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
-
#required_attachments ⇒ Object
Returns the value of attribute required_attachments.
-
#send_reminders ⇒ Object
Returns the value of attribute send_reminders.
-
#signers ⇒ Object
Returns the value of attribute signers.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#template ⇒ Object
Returns the value of attribute template.
-
#url ⇒ Object
Returns the value of attribute url.
-
#uuid ⇒ Object
Returns the value of attribute uuid.
-
#who ⇒ Object
Returns the value of attribute who.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SignRequestQuickCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SignRequestQuickCreate
Initializes the object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 194 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'from_email') self.from_email = attributes[:'from_email'] end if attributes.has_key?(:'from_email_name') self.from_email_name = attributes[:'from_email_name'] end if attributes.has_key?(:'is_being_prepared') self.is_being_prepared = attributes[:'is_being_prepared'] end if attributes.has_key?(:'prepare_url') self.prepare_url = attributes[:'prepare_url'] end if attributes.has_key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.has_key?(:'required_attachments') if (value = attributes[:'required_attachments']).is_a?(Array) self. = value end end if attributes.has_key?(:'disable_attachments') self. = attributes[:'disable_attachments'] end if attributes.has_key?(:'disable_text_signatures') self.disable_text_signatures = attributes[:'disable_text_signatures'] end if attributes.has_key?(:'disable_text') self.disable_text = attributes[:'disable_text'] end if attributes.has_key?(:'disable_date') self.disable_date = attributes[:'disable_date'] end if attributes.has_key?(:'disable_emails') self.disable_emails = attributes[:'disable_emails'] end if attributes.has_key?(:'disable_upload_signatures') self.disable_upload_signatures = attributes[:'disable_upload_signatures'] end if attributes.has_key?(:'subject') self.subject = attributes[:'subject'] end if attributes.has_key?(:'message') self. = attributes[:'message'] end if attributes.has_key?(:'who') self.who = attributes[:'who'] else self.who = "o" end if attributes.has_key?(:'send_reminders') self.send_reminders = attributes[:'send_reminders'] end if attributes.has_key?(:'signers') if (value = attributes[:'signers']).is_a?(Array) self.signers = value end end if attributes.has_key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.has_key?(:'url') self.url = attributes[:'url'] end if attributes.has_key?(:'document') self.document = attributes[:'document'] end if attributes.has_key?(:'integration') self.integration = attributes[:'integration'] end if attributes.has_key?(:'integration_data') self.integration_data = attributes[:'integration_data'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.has_key?(:'frontend_id') self.frontend_id = attributes[:'frontend_id'] end if attributes.has_key?(:'file') self.file = attributes[:'file'] end if attributes.has_key?(:'file_from_url') self.file_from_url = attributes[:'file_from_url'] end if attributes.has_key?(:'events_callback_url') self.events_callback_url = attributes[:'events_callback_url'] end if attributes.has_key?(:'file_from_content') self.file_from_content = attributes[:'file_from_content'] end if attributes.has_key?(:'file_from_content_name') self.file_from_content_name = attributes[:'file_from_content_name'] end if attributes.has_key?(:'template') self.template = attributes[:'template'] end if attributes.has_key?(:'prefill_tags') if (value = attributes[:'prefill_tags']).is_a?(Array) self. = value end end if attributes.has_key?(:'integrations') if (value = attributes[:'integrations']).is_a?(Array) self.integrations = value end end if attributes.has_key?(:'file_from_sf') self.file_from_sf = attributes[:'file_from_sf'] end if attributes.has_key?(:'auto_delete_days') self.auto_delete_days = attributes[:'auto_delete_days'] end end |
Instance Attribute Details
#auto_delete_days ⇒ Object
Returns the value of attribute auto_delete_days.
86 87 88 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 86 def auto_delete_days @auto_delete_days end |
#disable_attachments ⇒ Object
Returns the value of attribute disable_attachments.
30 31 32 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 30 def end |
#disable_date ⇒ Object
Returns the value of attribute disable_date.
36 37 38 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 36 def disable_date @disable_date end |
#disable_emails ⇒ Object
Returns the value of attribute disable_emails.
38 39 40 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 38 def disable_emails @disable_emails end |
#disable_text ⇒ Object
Returns the value of attribute disable_text.
34 35 36 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 34 def disable_text @disable_text end |
#disable_text_signatures ⇒ Object
Returns the value of attribute disable_text_signatures.
32 33 34 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 32 def disable_text_signatures @disable_text_signatures end |
#disable_upload_signatures ⇒ Object
Returns the value of attribute disable_upload_signatures.
40 41 42 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 40 def disable_upload_signatures @disable_upload_signatures end |
#document ⇒ Object
Returns the value of attribute document.
56 57 58 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 56 def document @document end |
#events_callback_url ⇒ Object
Returns the value of attribute events_callback_url.
72 73 74 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 72 def events_callback_url @events_callback_url end |
#external_id ⇒ Object
Returns the value of attribute external_id.
64 65 66 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 64 def external_id @external_id end |
#file ⇒ Object
Returns the value of attribute file.
68 69 70 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 68 def file @file end |
#file_from_content ⇒ Object
Returns the value of attribute file_from_content.
74 75 76 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 74 def file_from_content @file_from_content end |
#file_from_content_name ⇒ Object
Returns the value of attribute file_from_content_name.
76 77 78 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 76 def file_from_content_name @file_from_content_name end |
#file_from_sf ⇒ Object
Returns the value of attribute file_from_sf.
84 85 86 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 84 def file_from_sf @file_from_sf end |
#file_from_url ⇒ Object
Returns the value of attribute file_from_url.
70 71 72 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 70 def file_from_url @file_from_url end |
#from_email ⇒ Object
Returns the value of attribute from_email.
18 19 20 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 18 def from_email @from_email end |
#from_email_name ⇒ Object
Returns the value of attribute from_email_name.
20 21 22 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 20 def from_email_name @from_email_name end |
#frontend_id ⇒ Object
Returns the value of attribute frontend_id.
66 67 68 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 66 def frontend_id @frontend_id end |
#integration ⇒ Object
Returns the value of attribute integration.
58 59 60 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 58 def integration @integration end |
#integration_data ⇒ Object
Returns the value of attribute integration_data.
60 61 62 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 60 def integration_data @integration_data end |
#integrations ⇒ Object
Returns the value of attribute integrations.
82 83 84 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 82 def integrations @integrations end |
#is_being_prepared ⇒ Object
Returns the value of attribute is_being_prepared.
22 23 24 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 22 def is_being_prepared @is_being_prepared end |
#message ⇒ Object
Returns the value of attribute message.
44 45 46 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 44 def end |
#name ⇒ Object
Returns the value of attribute name.
62 63 64 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 62 def name @name end |
#prefill_tags ⇒ Object
Returns the value of attribute prefill_tags.
80 81 82 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 80 def end |
#prepare_url ⇒ Object
Returns the value of attribute prepare_url.
24 25 26 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 24 def prepare_url @prepare_url end |
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
26 27 28 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 26 def redirect_url @redirect_url end |
#required_attachments ⇒ Object
Returns the value of attribute required_attachments.
28 29 30 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 28 def end |
#send_reminders ⇒ Object
Returns the value of attribute send_reminders.
48 49 50 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 48 def send_reminders @send_reminders end |
#signers ⇒ Object
Returns the value of attribute signers.
50 51 52 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 50 def signers @signers end |
#subject ⇒ Object
Returns the value of attribute subject.
42 43 44 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 42 def subject @subject end |
#template ⇒ Object
Returns the value of attribute template.
78 79 80 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 78 def template @template end |
#url ⇒ Object
Returns the value of attribute url.
54 55 56 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 54 def url @url end |
#uuid ⇒ Object
Returns the value of attribute uuid.
52 53 54 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 52 def uuid @uuid end |
#who ⇒ Object
Returns the value of attribute who.
46 47 48 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 46 def who @who end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 111 def self.attribute_map { :'from_email' => :'from_email', :'from_email_name' => :'from_email_name', :'is_being_prepared' => :'is_being_prepared', :'prepare_url' => :'prepare_url', :'redirect_url' => :'redirect_url', :'required_attachments' => :'required_attachments', :'disable_attachments' => :'disable_attachments', :'disable_text_signatures' => :'disable_text_signatures', :'disable_text' => :'disable_text', :'disable_date' => :'disable_date', :'disable_emails' => :'disable_emails', :'disable_upload_signatures' => :'disable_upload_signatures', :'subject' => :'subject', :'message' => :'message', :'who' => :'who', :'send_reminders' => :'send_reminders', :'signers' => :'signers', :'uuid' => :'uuid', :'url' => :'url', :'document' => :'document', :'integration' => :'integration', :'integration_data' => :'integration_data', :'name' => :'name', :'external_id' => :'external_id', :'frontend_id' => :'frontend_id', :'file' => :'file', :'file_from_url' => :'file_from_url', :'events_callback_url' => :'events_callback_url', :'file_from_content' => :'file_from_content', :'file_from_content_name' => :'file_from_content_name', :'template' => :'template', :'prefill_tags' => :'prefill_tags', :'integrations' => :'integrations', :'file_from_sf' => :'file_from_sf', :'auto_delete_days' => :'auto_delete_days' } end |
.swagger_types ⇒ Object
Attribute type mapping.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 152 def self.swagger_types { :'from_email' => :'String', :'from_email_name' => :'String', :'is_being_prepared' => :'BOOLEAN', :'prepare_url' => :'String', :'redirect_url' => :'String', :'required_attachments' => :'Array<RequiredAttachment>', :'disable_attachments' => :'BOOLEAN', :'disable_text_signatures' => :'BOOLEAN', :'disable_text' => :'BOOLEAN', :'disable_date' => :'BOOLEAN', :'disable_emails' => :'BOOLEAN', :'disable_upload_signatures' => :'BOOLEAN', :'subject' => :'String', :'message' => :'String', :'who' => :'String', :'send_reminders' => :'BOOLEAN', :'signers' => :'Array<Signer>', :'uuid' => :'String', :'url' => :'String', :'document' => :'String', :'integration' => :'String', :'integration_data' => :'String', :'name' => :'String', :'external_id' => :'String', :'frontend_id' => :'String', :'file' => :'String', :'file_from_url' => :'String', :'events_callback_url' => :'String', :'file_from_content' => :'String', :'file_from_content_name' => :'String', :'template' => :'String', :'prefill_tags' => :'Array<InlinePrefillTags>', :'integrations' => :'Array<InlineIntegrationData>', :'file_from_sf' => :'FileFromSf', :'auto_delete_days' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 606 def ==(o) return true if self.equal?(o) self.class == o.class && from_email == o.from_email && from_email_name == o.from_email_name && is_being_prepared == o.is_being_prepared && prepare_url == o.prepare_url && redirect_url == o.redirect_url && == o. && == o. && disable_text_signatures == o.disable_text_signatures && disable_text == o.disable_text && disable_date == o.disable_date && disable_emails == o.disable_emails && disable_upload_signatures == o.disable_upload_signatures && subject == o.subject && == o. && who == o.who && send_reminders == o.send_reminders && signers == o.signers && uuid == o.uuid && url == o.url && document == o.document && integration == o.integration && integration_data == o.integration_data && name == o.name && external_id == o.external_id && frontend_id == o.frontend_id && file == o.file && file_from_url == o.file_from_url && events_callback_url == o.events_callback_url && file_from_content == o.file_from_content && file_from_content_name == o.file_from_content_name && template == o.template && == o. && integrations == o.integrations && file_from_sf == o.file_from_sf && auto_delete_days == o.auto_delete_days end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 682 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SignRequestClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 748 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 661 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
648 649 650 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 648 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
654 655 656 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 654 def hash [from_email, from_email_name, is_being_prepared, prepare_url, redirect_url, , , disable_text_signatures, disable_text, disable_date, disable_emails, disable_upload_signatures, subject, , who, send_reminders, signers, uuid, url, document, integration, integration_data, name, external_id, frontend_id, file, file_from_url, events_callback_url, file_from_content, file_from_content_name, template, , integrations, file_from_sf, auto_delete_days].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 354 def list_invalid_properties invalid_properties = Array.new if !@from_email.nil? && @from_email.to_s.length > 255 invalid_properties.push("invalid value for 'from_email', the character length must be smaller than or equal to 255.") end if !@from_email.nil? && @from_email.to_s.length < 1 invalid_properties.push("invalid value for 'from_email', the character length must be great than or equal to 1.") end if !@from_email_name.nil? && @from_email_name.to_s.length > 255 invalid_properties.push("invalid value for 'from_email_name', the character length must be smaller than or equal to 255.") end if !@prepare_url.nil? && @prepare_url.to_s.length < 1 invalid_properties.push("invalid value for 'prepare_url', the character length must be great than or equal to 1.") end if !@redirect_url.nil? && @redirect_url.to_s.length > 2100 invalid_properties.push("invalid value for 'redirect_url', the character length must be smaller than or equal to 2100.") end if !@subject.nil? && @subject.to_s.length > 512 invalid_properties.push("invalid value for 'subject', the character length must be smaller than or equal to 512.") end if @signers.nil? invalid_properties.push("invalid value for 'signers', signers cannot be nil.") end if !@uuid.nil? && @uuid.to_s.length < 1 invalid_properties.push("invalid value for 'uuid', the character length must be great than or equal to 1.") end if !@name.nil? && @name.to_s.length > 255 invalid_properties.push("invalid value for 'name', the character length must be smaller than or equal to 255.") end if !@external_id.nil? && @external_id.to_s.length > 255 invalid_properties.push("invalid value for 'external_id', the character length must be smaller than or equal to 255.") end if !@frontend_id.nil? && @frontend_id.to_s.length > 255 invalid_properties.push("invalid value for 'frontend_id', the character length must be smaller than or equal to 255.") end if !@file_from_url.nil? && @file_from_url.to_s.length > 2100 invalid_properties.push("invalid value for 'file_from_url', the character length must be smaller than or equal to 2100.") end if !@events_callback_url.nil? && @events_callback_url.to_s.length > 2100 invalid_properties.push("invalid value for 'events_callback_url', the character length must be smaller than or equal to 2100.") end if !@auto_delete_days.nil? && @auto_delete_days > 730 invalid_properties.push("invalid value for 'auto_delete_days', must be smaller than or equal to 730.") end if !@auto_delete_days.nil? && @auto_delete_days < 1 invalid_properties.push("invalid value for 'auto_delete_days', must be greater than or equal to 1.") end return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
728 729 730 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 728 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
734 735 736 737 738 739 740 741 742 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 734 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
722 723 724 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 722 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 421 def valid? return false if !@from_email.nil? && @from_email.to_s.length > 255 return false if !@from_email.nil? && @from_email.to_s.length < 1 return false if !@from_email_name.nil? && @from_email_name.to_s.length > 255 return false if !@prepare_url.nil? && @prepare_url.to_s.length < 1 return false if !@redirect_url.nil? && @redirect_url.to_s.length > 2100 return false if !@subject.nil? && @subject.to_s.length > 512 who_validator = EnumAttributeValidator.new('String', ["m", "mo", "o"]) return false unless who_validator.valid?(@who) return false if @signers.nil? return false if !@uuid.nil? && @uuid.to_s.length < 1 integration_validator = EnumAttributeValidator.new('String', ["mfiles", "salesforce", "formdesk", "zapier", "txhash"]) return false unless integration_validator.valid?(@integration) return false if !@name.nil? && @name.to_s.length > 255 return false if !@external_id.nil? && @external_id.to_s.length > 255 return false if !@frontend_id.nil? && @frontend_id.to_s.length > 255 return false if !@file_from_url.nil? && @file_from_url.to_s.length > 2100 return false if !@events_callback_url.nil? && @events_callback_url.to_s.length > 2100 return false if !@auto_delete_days.nil? && @auto_delete_days > 730 return false if !@auto_delete_days.nil? && @auto_delete_days < 1 return true end |