Class: SignRequestClient::Signer
- Inherits:
-
Object
- Object
- SignRequestClient::Signer
- Defined in:
- lib/signrequest_client/models/signer.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#after_document ⇒ Object
Returns the value of attribute after_document.
-
#approve_only ⇒ Object
Returns the value of attribute approve_only.
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#declined ⇒ Object
Returns the value of attribute declined.
-
#declined_on ⇒ Object
Returns the value of attribute declined_on.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#downloaded ⇒ Object
Returns the value of attribute downloaded.
-
#email ⇒ Object
Returns the value of attribute email.
-
#email_viewed ⇒ Object
Returns the value of attribute email_viewed.
-
#emailed ⇒ Object
Returns the value of attribute emailed.
-
#embed_url ⇒ Object
Returns the value of attribute embed_url.
-
#embed_url_user_id ⇒ Object
Returns the value of attribute embed_url_user_id.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#force_language ⇒ Object
Returns the value of attribute force_language.
-
#forwarded ⇒ Object
Returns the value of attribute forwarded.
-
#forwarded_on ⇒ Object
Returns the value of attribute forwarded_on.
-
#forwarded_reason ⇒ Object
Returns the value of attribute forwarded_reason.
-
#forwarded_to_email ⇒ Object
Returns the value of attribute forwarded_to_email.
-
#in_person ⇒ Object
Returns the value of attribute in_person.
-
#inputs ⇒ Object
Returns the value of attribute inputs.
-
#integrations ⇒ Object
Returns the value of attribute integrations.
-
#language ⇒ Object
Returns the value of attribute language.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#message ⇒ Object
Returns the value of attribute message.
-
#needs_to_sign ⇒ Object
Returns the value of attribute needs_to_sign.
-
#notify_only ⇒ Object
Returns the value of attribute notify_only.
-
#order ⇒ Object
Returns the value of attribute order.
-
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
-
#signed ⇒ Object
Returns the value of attribute signed.
-
#signed_on ⇒ Object
Returns the value of attribute signed_on.
-
#verify_bank_account ⇒ Object
Returns the value of attribute verify_bank_account.
-
#verify_phone_number ⇒ Object
Returns the value of attribute verify_phone_number.
-
#viewed ⇒ Object
Returns the value of attribute viewed.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Signer
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Signer
Initializes the object
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/signrequest_client/models/signer.rb', line 186 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'email') self.email = attributes[:'email'] end if attributes.has_key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.has_key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.has_key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.has_key?(:'email_viewed') self.email_viewed = attributes[:'email_viewed'] end if attributes.has_key?(:'viewed') self.viewed = attributes[:'viewed'] end if attributes.has_key?(:'signed') self.signed = attributes[:'signed'] end if attributes.has_key?(:'downloaded') self.downloaded = attributes[:'downloaded'] end if attributes.has_key?(:'signed_on') self.signed_on = attributes[:'signed_on'] end if attributes.has_key?(:'needs_to_sign') self.needs_to_sign = attributes[:'needs_to_sign'] else self.needs_to_sign = true end if attributes.has_key?(:'approve_only') self.approve_only = attributes[:'approve_only'] end if attributes.has_key?(:'notify_only') self.notify_only = attributes[:'notify_only'] end if attributes.has_key?(:'in_person') self.in_person = attributes[:'in_person'] end if attributes.has_key?(:'order') self.order = attributes[:'order'] end if attributes.has_key?(:'language') self.language = attributes[:'language'] end if attributes.has_key?(:'force_language') self.force_language = attributes[:'force_language'] end if attributes.has_key?(:'emailed') self.emailed = attributes[:'emailed'] end if attributes.has_key?(:'verify_phone_number') self.verify_phone_number = attributes[:'verify_phone_number'] end if attributes.has_key?(:'verify_bank_account') self.verify_bank_account = attributes[:'verify_bank_account'] end if attributes.has_key?(:'declined') self.declined = attributes[:'declined'] end if attributes.has_key?(:'declined_on') self.declined_on = attributes[:'declined_on'] end if attributes.has_key?(:'forwarded') self.forwarded = attributes[:'forwarded'] end if attributes.has_key?(:'forwarded_on') self.forwarded_on = attributes[:'forwarded_on'] end if attributes.has_key?(:'forwarded_to_email') self.forwarded_to_email = attributes[:'forwarded_to_email'] end if attributes.has_key?(:'forwarded_reason') self.forwarded_reason = attributes[:'forwarded_reason'] end if attributes.has_key?(:'message') self. = attributes[:'message'] end if attributes.has_key?(:'embed_url_user_id') self. = attributes[:'embed_url_user_id'] end if attributes.has_key?(:'inputs') if (value = attributes[:'inputs']).is_a?(Array) self.inputs = value end end if attributes.has_key?(:'embed_url') self. = attributes[:'embed_url'] end if attributes.has_key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end if attributes.has_key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.has_key?(:'after_document') self.after_document = attributes[:'after_document'] end if attributes.has_key?(:'integrations') if (value = attributes[:'integrations']).is_a?(Array) self.integrations = value end end end |
Instance Attribute Details
#after_document ⇒ Object
Returns the value of attribute after_document.
80 81 82 |
# File 'lib/signrequest_client/models/signer.rb', line 80 def after_document @after_document end |
#approve_only ⇒ Object
Returns the value of attribute approve_only.
38 39 40 |
# File 'lib/signrequest_client/models/signer.rb', line 38 def approve_only @approve_only end |
#attachments ⇒ Object
Returns the value of attribute attachments.
76 77 78 |
# File 'lib/signrequest_client/models/signer.rb', line 76 def @attachments end |
#declined ⇒ Object
Returns the value of attribute declined.
56 57 58 |
# File 'lib/signrequest_client/models/signer.rb', line 56 def declined @declined end |
#declined_on ⇒ Object
Returns the value of attribute declined_on.
58 59 60 |
# File 'lib/signrequest_client/models/signer.rb', line 58 def declined_on @declined_on end |
#display_name ⇒ Object
Returns the value of attribute display_name.
20 21 22 |
# File 'lib/signrequest_client/models/signer.rb', line 20 def display_name @display_name end |
#downloaded ⇒ Object
Returns the value of attribute downloaded.
32 33 34 |
# File 'lib/signrequest_client/models/signer.rb', line 32 def downloaded @downloaded end |
#email ⇒ Object
Returns the value of attribute email.
18 19 20 |
# File 'lib/signrequest_client/models/signer.rb', line 18 def email @email end |
#email_viewed ⇒ Object
Returns the value of attribute email_viewed.
26 27 28 |
# File 'lib/signrequest_client/models/signer.rb', line 26 def email_viewed @email_viewed end |
#emailed ⇒ Object
Returns the value of attribute emailed.
50 51 52 |
# File 'lib/signrequest_client/models/signer.rb', line 50 def emailed @emailed end |
#embed_url ⇒ Object
Returns the value of attribute embed_url.
74 75 76 |
# File 'lib/signrequest_client/models/signer.rb', line 74 def @embed_url end |
#embed_url_user_id ⇒ Object
Returns the value of attribute embed_url_user_id.
70 71 72 |
# File 'lib/signrequest_client/models/signer.rb', line 70 def @embed_url_user_id end |
#first_name ⇒ Object
Returns the value of attribute first_name.
22 23 24 |
# File 'lib/signrequest_client/models/signer.rb', line 22 def first_name @first_name end |
#force_language ⇒ Object
Returns the value of attribute force_language.
48 49 50 |
# File 'lib/signrequest_client/models/signer.rb', line 48 def force_language @force_language end |
#forwarded ⇒ Object
Returns the value of attribute forwarded.
60 61 62 |
# File 'lib/signrequest_client/models/signer.rb', line 60 def forwarded @forwarded end |
#forwarded_on ⇒ Object
Returns the value of attribute forwarded_on.
62 63 64 |
# File 'lib/signrequest_client/models/signer.rb', line 62 def forwarded_on @forwarded_on end |
#forwarded_reason ⇒ Object
Returns the value of attribute forwarded_reason.
66 67 68 |
# File 'lib/signrequest_client/models/signer.rb', line 66 def forwarded_reason @forwarded_reason end |
#forwarded_to_email ⇒ Object
Returns the value of attribute forwarded_to_email.
64 65 66 |
# File 'lib/signrequest_client/models/signer.rb', line 64 def forwarded_to_email @forwarded_to_email end |
#in_person ⇒ Object
Returns the value of attribute in_person.
42 43 44 |
# File 'lib/signrequest_client/models/signer.rb', line 42 def in_person @in_person end |
#inputs ⇒ Object
Returns the value of attribute inputs.
72 73 74 |
# File 'lib/signrequest_client/models/signer.rb', line 72 def inputs @inputs end |
#integrations ⇒ Object
Returns the value of attribute integrations.
82 83 84 |
# File 'lib/signrequest_client/models/signer.rb', line 82 def integrations @integrations end |
#language ⇒ Object
Returns the value of attribute language.
46 47 48 |
# File 'lib/signrequest_client/models/signer.rb', line 46 def language @language end |
#last_name ⇒ Object
Returns the value of attribute last_name.
24 25 26 |
# File 'lib/signrequest_client/models/signer.rb', line 24 def last_name @last_name end |
#message ⇒ Object
Returns the value of attribute message.
68 69 70 |
# File 'lib/signrequest_client/models/signer.rb', line 68 def @message end |
#needs_to_sign ⇒ Object
Returns the value of attribute needs_to_sign.
36 37 38 |
# File 'lib/signrequest_client/models/signer.rb', line 36 def needs_to_sign @needs_to_sign end |
#notify_only ⇒ Object
Returns the value of attribute notify_only.
40 41 42 |
# File 'lib/signrequest_client/models/signer.rb', line 40 def notify_only @notify_only end |
#order ⇒ Object
Returns the value of attribute order.
44 45 46 |
# File 'lib/signrequest_client/models/signer.rb', line 44 def order @order end |
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
78 79 80 |
# File 'lib/signrequest_client/models/signer.rb', line 78 def redirect_url @redirect_url end |
#signed ⇒ Object
Returns the value of attribute signed.
30 31 32 |
# File 'lib/signrequest_client/models/signer.rb', line 30 def signed @signed end |
#signed_on ⇒ Object
Returns the value of attribute signed_on.
34 35 36 |
# File 'lib/signrequest_client/models/signer.rb', line 34 def signed_on @signed_on end |
#verify_bank_account ⇒ Object
Returns the value of attribute verify_bank_account.
54 55 56 |
# File 'lib/signrequest_client/models/signer.rb', line 54 def verify_bank_account @verify_bank_account end |
#verify_phone_number ⇒ Object
Returns the value of attribute verify_phone_number.
52 53 54 |
# File 'lib/signrequest_client/models/signer.rb', line 52 def verify_phone_number @verify_phone_number end |
#viewed ⇒ Object
Returns the value of attribute viewed.
28 29 30 |
# File 'lib/signrequest_client/models/signer.rb', line 28 def viewed @viewed end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/signrequest_client/models/signer.rb', line 107 def self.attribute_map { :'email' => :'email', :'display_name' => :'display_name', :'first_name' => :'first_name', :'last_name' => :'last_name', :'email_viewed' => :'email_viewed', :'viewed' => :'viewed', :'signed' => :'signed', :'downloaded' => :'downloaded', :'signed_on' => :'signed_on', :'needs_to_sign' => :'needs_to_sign', :'approve_only' => :'approve_only', :'notify_only' => :'notify_only', :'in_person' => :'in_person', :'order' => :'order', :'language' => :'language', :'force_language' => :'force_language', :'emailed' => :'emailed', :'verify_phone_number' => :'verify_phone_number', :'verify_bank_account' => :'verify_bank_account', :'declined' => :'declined', :'declined_on' => :'declined_on', :'forwarded' => :'forwarded', :'forwarded_on' => :'forwarded_on', :'forwarded_to_email' => :'forwarded_to_email', :'forwarded_reason' => :'forwarded_reason', :'message' => :'message', :'embed_url_user_id' => :'embed_url_user_id', :'inputs' => :'inputs', :'embed_url' => :'embed_url', :'attachments' => :'attachments', :'redirect_url' => :'redirect_url', :'after_document' => :'after_document', :'integrations' => :'integrations' } end |
.swagger_types ⇒ Object
Attribute type mapping.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/signrequest_client/models/signer.rb', line 146 def self.swagger_types { :'email' => :'String', :'display_name' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'email_viewed' => :'BOOLEAN', :'viewed' => :'BOOLEAN', :'signed' => :'BOOLEAN', :'downloaded' => :'BOOLEAN', :'signed_on' => :'DateTime', :'needs_to_sign' => :'BOOLEAN', :'approve_only' => :'BOOLEAN', :'notify_only' => :'BOOLEAN', :'in_person' => :'BOOLEAN', :'order' => :'Integer', :'language' => :'String', :'force_language' => :'BOOLEAN', :'emailed' => :'BOOLEAN', :'verify_phone_number' => :'String', :'verify_bank_account' => :'String', :'declined' => :'BOOLEAN', :'declined_on' => :'DateTime', :'forwarded' => :'String', :'forwarded_on' => :'DateTime', :'forwarded_to_email' => :'String', :'forwarded_reason' => :'String', :'message' => :'String', :'embed_url_user_id' => :'String', :'inputs' => :'Array<SignerInputs>', :'embed_url' => :'String', :'attachments' => :'Array<SignerAttachment>', :'redirect_url' => :'String', :'after_document' => :'String', :'integrations' => :'Array<InlineDocumentSignerIntegrationData>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/signrequest_client/models/signer.rb', line 595 def ==(o) return true if self.equal?(o) self.class == o.class && email == o.email && display_name == o.display_name && first_name == o.first_name && last_name == o.last_name && email_viewed == o.email_viewed && viewed == o.viewed && signed == o.signed && downloaded == o.downloaded && signed_on == o.signed_on && needs_to_sign == o.needs_to_sign && approve_only == o.approve_only && notify_only == o.notify_only && in_person == o.in_person && order == o.order && language == o.language && force_language == o.force_language && emailed == o.emailed && verify_phone_number == o.verify_phone_number && verify_bank_account == o.verify_bank_account && declined == o.declined && declined_on == o.declined_on && forwarded == o.forwarded && forwarded_on == o.forwarded_on && forwarded_to_email == o.forwarded_to_email && forwarded_reason == o.forwarded_reason && == o. && == o. && inputs == o.inputs && == o. && == o. && redirect_url == o.redirect_url && after_document == o.after_document && integrations == o.integrations end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/signrequest_client/models/signer.rb', line 669 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SignRequestClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/signrequest_client/models/signer.rb', line 735 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/signrequest_client/models/signer.rb', line 648 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
635 636 637 |
# File 'lib/signrequest_client/models/signer.rb', line 635 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
641 642 643 |
# File 'lib/signrequest_client/models/signer.rb', line 641 def hash [email, display_name, first_name, last_name, email_viewed, viewed, signed, downloaded, signed_on, needs_to_sign, approve_only, notify_only, in_person, order, language, force_language, emailed, verify_phone_number, verify_bank_account, declined, declined_on, forwarded, forwarded_on, forwarded_to_email, forwarded_reason, , , inputs, , , redirect_url, after_document, integrations].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/signrequest_client/models/signer.rb', line 336 def list_invalid_properties invalid_properties = Array.new if @email.nil? invalid_properties.push("invalid value for 'email', email cannot be nil.") end if @email.to_s.length > 255 invalid_properties.push("invalid value for 'email', the character length must be smaller than or equal to 255.") end if @email.to_s.length < 1 invalid_properties.push("invalid value for 'email', the character length must be great than or equal to 1.") end if !@display_name.nil? && @display_name.to_s.length < 1 invalid_properties.push("invalid value for 'display_name', the character length must be great than or equal to 1.") end if !@first_name.nil? && @first_name.to_s.length > 255 invalid_properties.push("invalid value for 'first_name', the character length must be smaller than or equal to 255.") end if !@last_name.nil? && @last_name.to_s.length > 255 invalid_properties.push("invalid value for 'last_name', the character length must be smaller than or equal to 255.") end if !@order.nil? && @order > 2147483647 invalid_properties.push("invalid value for 'order', must be smaller than or equal to 2147483647.") end if !@order.nil? && @order < 0 invalid_properties.push("invalid value for 'order', must be greater than or equal to 0.") end if !@verify_phone_number.nil? && @verify_phone_number.to_s.length > 255 invalid_properties.push("invalid value for 'verify_phone_number', the character length must be smaller than or equal to 255.") end if !@verify_bank_account.nil? && @verify_bank_account.to_s.length > 255 invalid_properties.push("invalid value for 'verify_bank_account', the character length must be smaller than or equal to 255.") end if !@forwarded_to_email.nil? && @forwarded_to_email.to_s.length < 1 invalid_properties.push("invalid value for 'forwarded_to_email', the character length must be great than or equal to 1.") end if !@forwarded_reason.nil? && @forwarded_reason.to_s.length < 1 invalid_properties.push("invalid value for 'forwarded_reason', the character length must be great than or equal to 1.") end if !@message.nil? && @message.to_s.length < 1 invalid_properties.push("invalid value for 'message', the character length must be great than or equal to 1.") end if !@embed_url_user_id.nil? && @embed_url_user_id.to_s.length > 255 invalid_properties.push("invalid value for 'embed_url_user_id', the character length must be smaller than or equal to 255.") end if !@embed_url.nil? && @embed_url.to_s.length < 1 invalid_properties.push("invalid value for 'embed_url', the character length must be great than or equal to 1.") end if !@redirect_url.nil? && @redirect_url.to_s.length > 2100 invalid_properties.push("invalid value for 'redirect_url', the character length must be smaller than or equal to 2100.") end return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
715 716 717 |
# File 'lib/signrequest_client/models/signer.rb', line 715 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
721 722 723 724 725 726 727 728 729 |
# File 'lib/signrequest_client/models/signer.rb', line 721 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
709 710 711 |
# File 'lib/signrequest_client/models/signer.rb', line 709 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/signrequest_client/models/signer.rb', line 407 def valid? return false if @email.nil? return false if @email.to_s.length > 255 return false if @email.to_s.length < 1 return false if !@display_name.nil? && @display_name.to_s.length < 1 return false if !@first_name.nil? && @first_name.to_s.length > 255 return false if !@last_name.nil? && @last_name.to_s.length > 255 return false if !@order.nil? && @order > 2147483647 return false if !@order.nil? && @order < 0 language_validator = EnumAttributeValidator.new('String', ["en", "en-gb", "nl", "fr", "de", "he", "da", "fi", "hu", "it", "no", "pl", "pt", "es", "sv", "ru"]) return false unless language_validator.valid?(@language) return false if !@verify_phone_number.nil? && @verify_phone_number.to_s.length > 255 return false if !@verify_bank_account.nil? && @verify_bank_account.to_s.length > 255 return false if !@forwarded_to_email.nil? && @forwarded_to_email.to_s.length < 1 return false if !@forwarded_reason.nil? && @forwarded_reason.to_s.length < 1 return false if !@message.nil? && @message.to_s.length < 1 return false if !@embed_url_user_id.nil? && @embed_url_user_id.to_s.length > 255 return false if !@embed_url.nil? && @embed_url.to_s.length < 1 return false if !@redirect_url.nil? && @redirect_url.to_s.length > 2100 return true end |