Method: SignRequestClient::SignRequestQuickCreate#list_invalid_properties
- Defined in:
- lib/signrequest_client/models/sign_request_quick_create.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/signrequest_client/models/sign_request_quick_create.rb', line 354 def list_invalid_properties invalid_properties = Array.new if !@from_email.nil? && @from_email.to_s.length > 255 invalid_properties.push("invalid value for 'from_email', the character length must be smaller than or equal to 255.") end if !@from_email.nil? && @from_email.to_s.length < 1 invalid_properties.push("invalid value for 'from_email', the character length must be great than or equal to 1.") end if !@from_email_name.nil? && @from_email_name.to_s.length > 255 invalid_properties.push("invalid value for 'from_email_name', the character length must be smaller than or equal to 255.") end if !@prepare_url.nil? && @prepare_url.to_s.length < 1 invalid_properties.push("invalid value for 'prepare_url', the character length must be great than or equal to 1.") end if !@redirect_url.nil? && @redirect_url.to_s.length > 2100 invalid_properties.push("invalid value for 'redirect_url', the character length must be smaller than or equal to 2100.") end if !@subject.nil? && @subject.to_s.length > 512 invalid_properties.push("invalid value for 'subject', the character length must be smaller than or equal to 512.") end if @signers.nil? invalid_properties.push("invalid value for 'signers', signers cannot be nil.") end if !@uuid.nil? && @uuid.to_s.length < 1 invalid_properties.push("invalid value for 'uuid', the character length must be great than or equal to 1.") end if !@name.nil? && @name.to_s.length > 255 invalid_properties.push("invalid value for 'name', the character length must be smaller than or equal to 255.") end if !@external_id.nil? && @external_id.to_s.length > 255 invalid_properties.push("invalid value for 'external_id', the character length must be smaller than or equal to 255.") end if !@frontend_id.nil? && @frontend_id.to_s.length > 255 invalid_properties.push("invalid value for 'frontend_id', the character length must be smaller than or equal to 255.") end if !@file_from_url.nil? && @file_from_url.to_s.length > 2100 invalid_properties.push("invalid value for 'file_from_url', the character length must be smaller than or equal to 2100.") end if !@events_callback_url.nil? && @events_callback_url.to_s.length > 2100 invalid_properties.push("invalid value for 'events_callback_url', the character length must be smaller than or equal to 2100.") end if !@auto_delete_days.nil? && @auto_delete_days > 730 invalid_properties.push("invalid value for 'auto_delete_days', must be smaller than or equal to 730.") end if !@auto_delete_days.nil? && @auto_delete_days < 1 invalid_properties.push("invalid value for 'auto_delete_days', must be greater than or equal to 1.") end return invalid_properties end |